****************************
Function Reference by Module
****************************

.. automodule:: viziphant.rasterplot

.. automodule:: viziphant.statistics

.. automodule:: viziphant.spike_train_correlation

.. automodule:: viziphant.spike_train_synchrony

.. automodule:: viziphant.events

.. automodule:: viziphant.patterns

.. automodule:: viziphant.gpfa

.. automodule:: viziphant.unitary_event_analysis

.. automodule:: viziphant.asset


References
----------

.. bibliography::
